IgnoreFilesBuilder

Struct IgnoreFilesBuilder 

pub struct IgnoreFilesBuilder { /* private fields */ }
Builder for generating multiple ignore files.

Example

use cuenv_ignore::{IgnoreFile, IgnoreFiles};

let result = IgnoreFiles::builder()
    .directory("/path/to/project")
    .require_git_repo(true)
    .dry_run(false)
    .file(IgnoreFile::new("git")
        .pattern("node_modules/")
        .pattern(".env"))
    .file(IgnoreFile::new("docker")
        .pattern("target/"))
    .generate()?;

Implementations

Source

impl IgnoreFilesBuilder

pub fn directory(self, dir: impl AsRef<Path>) -> Self

Set the directory where ignore files will be generated.

Defaults to the current directory if not set.

pub fn file(self, file: IgnoreFile) -> Self

Add a single ignore file configuration.

pub fn files(self, files: impl IntoIterator<Item = IgnoreFile>) -> Self

Add multiple ignore file configurations.

pub fn require_git_repo(self, require: bool) -> Self

Require that the directory is within a Git repository.

Defaults to false. When true, returns an error if the directory is not within a Git repository.

pub fn dry_run(self, dry_run: bool) -> Self

Enable dry-run mode.

When true, no files will be written. The result will indicate what would happen with WouldCreate and WouldUpdate statuses.

pub fn generate(self) -> Result<SyncResult>

Generate the ignore files.

Errors

Returns an error if:

  • require_git_repo is true and the directory is not within a Git repository
  • A tool name contains invalid characters (path separators)
  • File I/O fails